@@ -20,9 +20,6 @@ wget -nv "$MJ_TARBALL"
 tar xzf "$BRANCH.tar.gz"
 rm "$BRANCH.tar.gz"
 
-# That theme contains compressed jQuery without source
-rm -rf "MathJax-docs-$BRANCH/_themes/sphinx-bootstrap"
-
 BASEVERSION=`grep ^version "MathJax-docs-$BRANCH/conf.py" | grep '[0-9.]*' -o`
 VERSION="$BASEVERSION+$DATE"
 FILENAME="mathjax-docs_$VERSION.orig.tar.gz"
